==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebToastDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToastDescription } from "./WebToastDescription";
/**
 * @hidden
 */
export let WebToastDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToastDescriptionMetadata extends Base {
        static b(a) {
            if (WebToastDescriptionMetadata.a == null) {
                WebToastDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToastDescriptionMetadata.c(WebToastDescriptionMetadata.a);
            }
            if (a.k(WebToastDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebToastDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Toast");
            a.item("__tagNameWC", "String:igc-toast");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Open", "Boolean");
            a.item("DisplayTime", "Number:double");
            a.item("KeepOpen", "Boolean");
        }
        static d(a) {
            WebToastDescriptionMetadata.b(a);
            a.ad("WebToast", () => new WebToastDescription());
            a.ac("WebToast", WebToastDescriptionMetadata.a);
        }
    }
    WebToastDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToastDescriptionMetadata, 'WebToastDescriptionMetadata');
    WebToastDescriptionMetadata.a = null;
    return WebToastDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebToastDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseAlertLikeDescriptionMetadata } from "./WebBaseAlertLikeDescriptionMetadata";
import { WebToastDescription } from "./WebToastDescription";
/**
 * @hidden
 */
export let WebToastDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToastDescriptionMetadata extends Base {
        static b(a) {
            if (WebToastDescriptionMetadata.a == null) {
                WebToastDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToastDescriptionMetadata.c(WebToastDescriptionMetadata.a);
            }
            if (a.k(WebToastDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebToastDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseAlertLikeDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Toast");
            a.item("__tagNameWC", "String:igc-toast");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebToastDescriptionMetadata.b(a);
            a.ae("WebToast", () => new WebToastDescription());
            a.ad("WebToast", WebToastDescriptionMetadata.a);
        }
    }
    WebToastDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToastDescriptionMetadata, 'WebToastDescriptionMetadata');
    WebToastDescriptionMetadata.a = null;
    return WebToastDescriptionMetadata;
})();
